@@ -1,6 +1,7 @@
 """An example script that uses the functionality of robot_kit"""
 from robot_kit.leds import NeoPixelStrip
 from robot_kit.wheels import Wheels
+from robot_kit.ultrasonic import Ultrasonic
 import time
 
 
@@ -22,3 +23,9 @@ if __name__ == '__main__':
     wheels.all(0.25)
     time.sleep(1.0)
     wheels.stop()
+
+    # Get the distance from the Ultrasonic sensor
+    dis_sensor = Ultrasonic()
+    for i in range(50):
+        print(dis_sensor.get_distance())
+        time.sleep(0.25)
